@@ -32,6 +32,7 @@ def test_good_no_defaults():
             - options.py
             - $VAR/a.py
         wg: Charm
+        inform: a.b@c.d
     """
     )
     data = LbAPCommon.parse_yaml(rendered_yaml)
@@ -42,7 +43,7 @@ def test_good_no_defaults():
     assert data["job_1"]["options"] == ["options.py", "$VAR/a.py"]
     assert data["job_1"]["wg"] == "Charm"
     assert data["job_1"]["automatically_configure"] is False
-    assert data["job_1"]["inform"] == []
+    assert data["job_1"]["inform"] == "a.b@c.d"
 
 
 def test_good_with_defaults():
@@ -95,7 +96,9 @@ def test_good_with_defaults():
     assert data["job_2"]["inform"] == ["other@example.com"]
 
 
-@pytest.mark.parametrize("missing_key", ["application", "input", "output", "wg"])
+@pytest.mark.parametrize(
+    "missing_key", ["application", "input", "output", "wg", "inform"]
+)
 def test_bad_missing_key(missing_key):
     data = {
         "job_1": {
@@ -104,6 +107,7 @@ def test_bad_missing_key(missing_key):
             "output": "FILETYPE.ROOT",
             "options": ["options.py"],
             "wg": "Charm",
+            "inform": "a.b@c.d",
         }
     }
     del data["job_1"][missing_key]
